==> components-2.0.10.tgz: package/esm/Atoms/Tabs/TabMenuItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-5kcyjn-0"
})(["position:relative;flex:1 auto;flex-direction:row;justify-content:flex-start;align-items:center;padding:1rem;box-sizing:border-box;cursor:pointer;@media (max-width:48rem){order:1;&.hidden{order:2;}}@media (min-width:48rem){display:flex;justify-content:center;order:1;&:hover{&:last-child{opacity:1;}}}"]);
var Bar =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-5kcyjn-1"
})(["position:absolute;bottom:-2px;left:0;width:100%;height:0.2rem;transition-duration:0.3s;transition-timing-function:ease-in-out;background-color:", ";opacity:", ";"], function (props) {
  return props.theme['tabMenuBarColor'];
}, function (props) {
  return props.selected ? '1' : '0';
});

var TabMenuItem = function TabMenuItem(_ref) {
  var children = _ref.children,
      className = _ref.className,
      selected = _ref.selected,
      rest = _objectWithoutProperties(_ref, ["children", "className", "selected"]);

  return React.createElement(Wrapper, _extends({
    className: selected ? className : "".concat(className, " disabled")
  }, rest), children, React.createElement(Bar, {
    selected: selected
  }));
};

TabMenuItem.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node,
  className: PropTypes.string,
  selected: PropTypes.bool
} : {};
TabMenuItem.defaultProps = {
  selected: false
};
export default TabMenuItem;

==> components-2.0.12.tgz: package/esm/Atoms/Tabs/TabMenuItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-5kcyjn-0"
})(["\n  position: relative;\n  flex: 1 auto;\n  flex-direction: row;\n  justify-content: flex-start;\n  align-items: center;\n  padding: 1rem;\n  box-sizing: border-box;\n  cursor: pointer;\n\n  @media (max-width: 48rem) {\n    order: 1;\n\n    &.hidden {\n      order: 2;\n    }\n  }\n\n  @media (min-width: 48rem) {\n    display: flex;\n    justify-content: center;\n    order: 1;\n\n    &:hover {\n      & :last-child {\n        opacity: 1;\n      }\n    }\n  }\n"]);
var Bar =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-5kcyjn-1"
})(["\n  position: absolute;\n  bottom: -2px;\n  left: 0;\n  width: 100%;\n  height: 0.2rem;\n  transition-duration: 0.3s;\n  transition-timing-function: ease-in-out;\n  background-color: ", ";\n  opacity: ", ";\n"], function (props) {
  return props.theme['tabMenuBarColor'];
}, function (props) {
  return props.selected ? '1' : '0';
});

var TabMenuItem = function TabMenuItem(_ref) {
  var children = _ref.children,
      className = _ref.className,
      selected = _ref.selected,
      rest = _objectWithoutProperties(_ref, ["children", "className", "selected"]);

  return React.createElement(Wrapper, _extends({
    className: selected ? className : "".concat(className, " disabled")
  }, rest), children, React.createElement(Bar, {
    selected: selected
  }));
};

TabMenuItem.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node,
  className: PropTypes.string,
  selected: PropTypes.bool
} : {};
TabMenuItem.defaultProps = {
  selected: false
};
export default TabMenuItem;
